﻿/*	File			DNS_ResolverDlg.cs
	Purpose			Demonstration of the use of the gethostbyname DS resolver
	Author			Richard Anthony	(ar26@gre.ac.uk)
	Date			August 2014
*/

using System;
using System.Text;
using System.Net;
using System.Net.Sockets;
using System.Windows.Forms;

namespace DNS_Resolver
{
    public partial class CDNS_Resolver : Form
    {
        public CDNS_Resolver()
        {
            InitializeComponent();
            MachineName_textBox.Enabled = false;
            AddressType_textBox.Enabled = false;
            Local_IP_Address_listBox.Enabled = false;
            IP_Address_listBox.Enabled = false;
            GetLocalHostAddressDetails();
        }

        void GetLocalHostAddressDetails()
        {
            string sHost = Dns.GetHostName(); // Get the local host's name
            MachineName_textBox.Text = sHost;

            try
            {
                IPHostEntry IP_host = Dns.GetHostEntry(sHost);
                foreach (IPAddress IP_address in IP_host.AddressList)
                {
                    if (AddressFamily.InterNetwork == IP_address.AddressFamily)
                    {
                        string sAddress = IP_address.ToString();
                        Local_IP_Address_listBox.Items.Add(sAddress);
                        AddressType_textBox.Text = "IPv4";
                    }
                }
            }
            catch (SocketException ex)
            {
                Local_IP_Address_listBox.Items.Add(ex.Message.ToString());
            }
        }

        private void Do_Resolve()
        {
            IP_Address_listBox.Items.Clear();
            Resolve_button.Enabled = false;
            DomainName_textBox.Enabled = false;

            string sHost = DomainName_textBox.Text; // Get the textual name provided by the user
            if ("" == sHost)
            {
                IP_Address_listBox.Items.Add("Host / domain name is blank");
                Resolve_button.Enabled = true;
                DomainName_textBox.Enabled = true;
                return;
            }

            try
            {
                IPHostEntry IP_host = Dns.GetHostEntry(sHost);
                foreach (IPAddress IP_address in IP_host.AddressList)
                {
                    if (AddressFamily.InterNetwork == IP_address.AddressFamily)
                    {
                        string sAddress = IP_address.ToString();
                        IP_Address_listBox.Items.Add(sAddress);
                    }
                }
            }
            catch (SocketException ex)
            {
                IP_Address_listBox.Items.Add(ex.Message.ToString());
            }
            Resolve_button.Enabled = true;
            DomainName_textBox.Enabled = true;
        }

        private void Resolve_button_Click(object sender, EventArgs e)
        {
            Do_Resolve();
        }

        private void Done_button_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }
    }
}
